@@ -1,5 +1,3 @@
-#define QT_FEATURE_ffmpeg 1
-
 #define QT_FEATURE_pipewire 1
 
 #define QT_FEATURE_pipewire_screencapture 1
@@ -36,17 +34,21 @@
 
 #define QT_FEATURE_native_android_backend -1
 
+#define QT_FEATURE_native_windows_backend -1
+
 #define QT_FEATURE_pulseaudio 1
 
-#define QT_FEATURE_opensles -1
+#define QT_FEATURE_aaudio -1
 
 #define QT_FEATURE_wasm -1
 
-#define QT_FEATURE_wmf -1
+#define QT_FEATURE_wasapi -1
 
 #define QT_FEATURE_spatialaudio 1
 
 #define QT_FEATURE_spatialaudio_quick3d 1
 
+#define QT_FEATURE_ffmpeg 1
+
 #define QT_FEATURE_ffmpeg_stubs -1
 
